# Release History

## 1.0.0 (08/02/2022)

- Initial Release

- Configured, CHANGELOG, LICENSE, and MANIFEST

- Connect to cloud-based or IoT Edge-based storage accounts

- Connect via connection string or storage account key
